"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const async_1 = require("./async");
const commander_1 = require("commander");
const packageJson = require("../package.json");
const cp = require("child_process");
const uuid_1 = require("uuid");
const chalk_1 = require("chalk");
const os_1 = require("os");
const spinner_1 = require("./spinner");
const COMMANDS = {
    check: "git --version",
    clone: "git clone"
};
const GITHUB_WEBSITE = "https://github.com";
const TEMP_DIR = `${os_1.tmpdir}${uuid_1.v4()}`;
const EDITOR = process.env.EDITOR;
const logger = (message, type) => (...args) => console[type](...args, message);
(async () => {
    let repoName;
    new commander_1.Command(packageJson.name)
        .version(packageJson.version)
        .arguments("<repo-name>")
        .usage(`${chalk_1.default.green("<repo-name>")}`)
        .action(repo => {
        repoName = repo;
    })
        .parse(process.argv);
    try {
        await async_1.default.exec(COMMANDS.check);
    }
    catch (err) {
        logger(`unable to execute ${COMMANDS.check}`, "error")();
        logger(err, "error")();
    }
    repoName = repoName.trim();
    const command = `${COMMANDS.clone} ${GITHUB_WEBSITE}/${repoName} ${TEMP_DIR}`;
    let editor = EDITOR;
    try {
        await async_1.default.exec(command);
        editor = (await async_1.default.exec(`echo ${editor}`)).trim();
    }
    catch (err) {
        logger(`unable to execute ${command}`, "error")();
        logger(err, "error")();
    }
    spinner_1.default.end();
    cp.spawn(editor, [TEMP_DIR], { stdio: "inherit", shell: true });
})();
//# sourceMappingURL=index.js.map